@@ -38,11 +38,9 @@ class Hook(Node):
         with open(configpath) as jsonFile:
             self.version = json.load(jsonFile)["version"]
 
-        try:
-            with open(captionsPath) as jsonFile:
-                self.captions = json.load(jsonFile)
-        except:
-            print("Couldn't load captions")
+        with open(captionsPath) as jsonFile:
+            self.captions = json.load(jsonFile)
+
 
         #get connectHash
         self.initKwargs = kwargs
@@ -66,7 +64,7 @@ class Hook(Node):
         self.data = BTNexusData("https://" + self.host, self.token, self.config['id'])
         super(Hook, self).__init__(self.token, self.host)
         self.onInit(**kwargs)
-        self.connect()
+        self.connect(**kwargs)
 
 
     def onConnected(self):
@@ -107,7 +105,7 @@ class Hook(Node):
                         entities=kwargs["entities"], 
                         slots=kwargs["slots"], 
                         branchName=kwargs["branch"]["name"], 
-                        peer=kwargs)#TODO: what is needed peer? only needs infos to indentify message origin
+                        peer=kwargs)
 
     def onMessage(self, originalTxt, intent, language, entities, slots, branchName, peer):
         """
@@ -134,7 +132,7 @@ class Hook(Node):
         """
         self.say(peer, {'answer':"Hook needs to overload onMessage"})  # if not overloaded this is what your hook will say
 
-    def say(self, peer, message): # TODO: check if message is just a string wrap it in the answer field ;)
+    def say(self, peer, message): 
         """
         publishes the hooks response.
 
@@ -170,7 +168,7 @@ class Hook(Node):
         self.memoryData = {
                 'service': "hook",
                 'context': self.config['id'],
-                'version': self.version  #TODO: this should be the version of the implementation not the lib
+                'version': self.version  
                 }
         
 
